@@ -29,16 +29,16 @@ import tim.prune.gui.profile.ProfileChart;
 /**
  * GpsPrune is a tool to visualize, edit, convert and prune GPS data
  * Please see the included readme.txt or http://activityworkshop.net
- * This software is copyright activityworkshop.net 2006-2015 and made available through the Gnu GPL version 2.
+ * This software is copyright activityworkshop.net 2006-2016 and made available through the Gnu GPL version 2.
  * For license details please see the included license.txt.
  * GpsPrune is the main entry point to the application, including initialisation and launch
  */
 public class GpsPrune
 {
 	/** Version number of application, used in about screen and for version check */
-	public static final String VERSION_NUMBER = "18.3";
+	public static final String VERSION_NUMBER = "18.4";
 	/** Build number, just used for about screen */
-	public static final String BUILD_NUMBER = "336b";
+	public static final String BUILD_NUMBER = "340";
 	/** Static reference to App object */
 	private static App APP = null;
 
